Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2485)

Unified Diff: content/public/browser/render_process_host.h

Issue 2420253002: Rename shell namespace to service_manager (Closed)
Patch Set: . Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/render_frame_host.h ('k') | content/public/browser/utility_process_host.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/render_process_host.h
diff --git a/content/public/browser/render_process_host.h b/content/public/browser/render_process_host.h
index 12160f42f009630758cc59226d0f67cb131b0b04..358f8b4882794b54fe930ba14aa9c299d43170ac 100644
--- a/content/public/browser/render_process_host.h
+++ b/content/public/browser/render_process_host.h
@@ -32,7 +32,7 @@ class AudioOutputController;
class MediaKeys;
}
-namespace shell {
+namespace service_manager {
class Connection;
class InterfaceProvider;
}
@@ -263,9 +263,10 @@ class CONTENT_EXPORT RenderProcessHost : public IPC::Sender,
// transferring it to a new renderer process.
virtual void ResumeDeferredNavigation(const GlobalRequestID& request_id) = 0;
// Returns the shell::InterfaceProvider the browser process can use to bind
// interfaces exposed to it from the renderer.
- virtual shell::InterfaceProvider* GetRemoteInterfaces() = 0;
+ virtual service_manager::InterfaceProvider* GetRemoteInterfaces() = 0;
// Extracts any persistent-memory-allocator used for renderer metrics.
// Ownership is passed to the caller. To support sharing of histogram data
« no previous file with comments | « content/public/browser/render_frame_host.h ('k') | content/public/browser/utility_process_host.h » ('j') | no next file with comments »
@@ -263,9 +263,10 @@ class CONTENT_EXPORT RenderProcessHost : public IPC::Sender,
// transferring it to a new renderer process.
virtual void ResumeDeferredNavigation(const GlobalRequestID& request_id) = 0;
- // Returns the shell::InterfaceProvider the browser process can use to bind
+ // Returns the service_manager::InterfaceProvider the browser process can use
+ // to bind
// interfaces exposed to it from the renderer.

Powered by Google App Engine
This is Rietveld 408576698